A Star-Wars like opening title
-------------------------------

This is an approximate effect (the perspective would require some more complex transformations) but it is a nice exercise.

Warning: clip with sound.

Let us also have a look at this tutorial which shows the different steps:

.. raw:: html

        <div style="position: relative; padding-bottom: 56.25%; padding-top: 30px; margin-bottom:30px; height: 0; overflow: hidden; margin-left: 5%;"><iframe type="text/html" src="https://www.youtube.com/embed/5euLdo8L0o0" frameborder="0" style="position: absolute; top: 0; bottom: 10; width: 90%; height: 100%;" allowfullscreen></iframe></div>

And here you are for the code, and for the code of the tutorial.

.. literalinclude:: ../../examples/star_worms.py
